@@ -51,8 +51,8 @@ class Client:
             else:
                 raise Exception("bad message")
 
-    def get(self, symbol: bytes, data_type: bytes, end_timestamp: bytes):
-        mget = message.Get(symbol, data_type, end_timestamp)
+    def get(self, symbol: bytes, data_type: bytes, end_timestamp: bytes, format: bytes = b'json'):
+        mget = message.Get(symbol, data_type, end_timestamp, format)
         self.send(mget)
         res, raw_res = [], []
         while True:
@@ -66,13 +66,15 @@ class Client:
                 raise Exception(error_code)
 
         for raw_data in raw_res:
-            data = yaml.safe_load(raw_data.get_field('data').decode("utf-8"))
+            data_str = raw_data.get_field('data').decode("utf-8")
+            data_str = data_str.replace(",]","]").replace(",}","}")
+            data = ujson.loads(data_str)
             res.append(data)
         return res
 
-    def sub(self, symbols: list, data_type: bytes, sub_handler = None):
+    def sub(self, symbols: list, data_type: bytes, sub_handler = None, format: bytes = b"json"):
         for symbol in symbols:
-            msub = message.Sub(symbol, data_type)
+            msub = message.Sub(symbol, data_type, format)
             self.send(msub)
             
         while sub_handler:
